@@ -6,6 +6,18 @@
   Contents:     Conversion program for ELOG messages
 
   $Log: elconv.c,v $
+  Revision 1.8  2004/11/21 16:51:42  midas
+  Added debug print of dir
+
+  Revision 1.7  2004/09/18 04:42:46  midas
+  Fixed bug with not displaying inline images
+
+  Revision 1.6  2004/07/28 18:51:57  midas
+  Fixed error with gcc 3.4, thanks to Recai Oktas
+
+  Revision 1.5  2004/04/15 06:48:43  midas
+  Fixed bug with unterminated string
+
   Revision 1.4  2004/02/17 11:19:49  midas
   Fixed compiler warnings
 
@@ -266,14 +278,12 @@ INT ss_file_find(char *path, char *pattern, char **plist)
       return 0;
    first = 0;
    *plist = (char *) realloc(*plist, (i + 1) * MAX_PATH_LENGTH);
-   strncpy(*plist + (i * MAX_PATH_LENGTH), lpfdata->cFileName,
-           strlen(lpfdata->cFileName));
+   strncpy(*plist + (i * MAX_PATH_LENGTH), lpfdata->cFileName, strlen(lpfdata->cFileName));
    *(*plist + (i * MAX_PATH_LENGTH) + strlen(lpfdata->cFileName)) = '\0';
    i++;
    while (FindNextFile(pffile, lpfdata)) {
       *plist = (char *) realloc(*plist, (i + 1) * MAX_PATH_LENGTH);
-      strncpy(*plist + (i * MAX_PATH_LENGTH), lpfdata->cFileName,
-              strlen(lpfdata->cFileName));
+      strncpy(*plist + (i * MAX_PATH_LENGTH), lpfdata->cFileName, strlen(lpfdata->cFileName));
       *(*plist + (i * MAX_PATH_LENGTH) + strlen(lpfdata->cFileName)) = '\0';
       i++;
    }
@@ -290,7 +300,7 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
    struct tm *tms, ltms;
    time_t lt, ltime, lact;
    char str[256], file_name[256], dir[256];
-   char *file_list;
+   char *file_list, *tag_dir;
 
    did_walk = 0;
    ltime = lfh = 0;
@@ -300,9 +310,10 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
 
    /* check tag for direction */
    direction = 0;
-   if (strpbrk(tag, "+-")) {
-      direction = atoi(strpbrk(tag, "+-"));
-      *strpbrk(tag, "+-") = 0;
+   tag_dir = strpbrk(tag, "+-");
+   if (tag_dir) {
+      direction = atoi(tag_dir);
+      *tag_dir = 0;
    }
 
    /* if tag is given, open file directly */
@@ -332,8 +343,7 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
       do {
          tms = localtime(&ltime);
 
-         sprintf(file_name, "%s%02d%02d%02d.log", dir, tms->tm_year % 100,
-                 tms->tm_mon + 1, tms->tm_mday);
+         sprintf(file_name, "%s%02d%02d%02d.log", dir, tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday);
          lfh = open(file_name, O_RDWR | O_BINARY, 0644);
 
          if (lfh < 0) {
@@ -349,8 +359,7 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
 
             /* set new tag */
             tms = localtime(&ltime);
-            sprintf(tag, "%02d%02d%02d.0", tms->tm_year % 100, tms->tm_mon + 1,
-                    tms->tm_mday);
+            sprintf(tag, "%02d%02d%02d.0", tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday);
          }
 
          /* in forward direction, stop today */
@@ -451,8 +460,7 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
          do {
             lt -= 3600 * 24;
             tms = localtime(&lt);
-            sprintf(str, "%02d%02d%02d.0", tms->tm_year % 100, tms->tm_mon + 1,
-                    tms->tm_mday);
+            sprintf(str, "%02d%02d%02d.0", tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday);
 
             status = el_search_message(str, &lfh, FALSE, FALSE);
 
@@ -504,6 +512,7 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
          close(lfh);
          return EL_FILE_ERROR;
       }
+      str[15] = 0;
       lseek(lfh, -15, SEEK_CUR);
 
       if (strncmp(str, "$Start$: ", 9) == 0) {
@@ -524,8 +533,7 @@ INT el_search_message(char *tag, int *fh, BOOL walk, BOOL first)
          do {
             lt += 3600 * 24;
             tms = localtime(&lt);
-            sprintf(str, "%02d%02d%02d.0", tms->tm_year % 100, tms->tm_mon + 1,
-                    tms->tm_mday);
+            sprintf(str, "%02d%02d%02d.0", tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday);
 
             status = el_search_message(str, &lfh, FALSE, FALSE);
 
@@ -702,8 +710,7 @@ INT el_submit(char attr_name[MAX_N_ATTR][NAME_LENGTH],
       time(&now);
       tms = localtime(&now);
 
-      sprintf(file_name, "%s%02d%02d%02d.log", dir, tms->tm_year % 100, tms->tm_mon + 1,
-              tms->tm_mday);
+      sprintf(file_name, "%s%02d%02d%02d.log", dir, tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday);
 
       fh = open(file_name, O_CREAT | O_RDWR | O_BINARY, 0644);
       if (fh < 0)
@@ -780,8 +787,7 @@ INT el_submit(char attr_name[MAX_N_ATTR][NAME_LENGTH],
    size = strlen(message) + strlen(start_str) + strlen(end_str);
 
    if (tag != NULL && !bedit)
-      sprintf(tag, "%02d%02d%02d.%d", tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday,
-              (int) (TELL(fh)));
+      sprintf(tag, "%02d%02d%02d.%d", tms->tm_year % 100, tms->tm_mon + 1, tms->tm_mday, (int) (TELL(fh)));
 
    sprintf(start_str, "$Start$: %6d\n", size);
    sprintf(end_str, "$End$:   %6d\n\f", size);
@@ -1089,6 +1095,9 @@ int main(int argc, char *argv[])
    getcwd(data_dir, sizeof(data_dir));
    strcat(data_dir, DIR_SEPARATOR_STR);
 
+   if (verbose)
+      printf("Scanning directory \"%s\"\n", data_dir);
+
    scan_messages();
 
    return 0;
